@@ -121,7 +121,7 @@ class Button(HomeAssistant):
         self.domain = "button"
         super().__init__(*args, **kwargs)
 
-    def start(self) -> str:
+    def press(self) -> str:
         """Start button"""
         self.client.get_domain(self.domain).press(entity_id=self.entity_id)
         return "starting"
@@ -145,5 +145,5 @@ class TaylorSwiftly:
 
 
 if __name__ == "__main__":
-    alarm = Alarm()
-    print(alarm.status())
+    taylor = TaylorSwiftly()
+    taylor.start.press()
